==> gtkmm-1.3.10.tar.bz2: gtkmm-1.3.10/gtk/gtkmm/treeview_private.h <==
#ifndef _GTKMM_TREEVIEW_PRIVATE_H
#define _GTKMM_TREEVIEW_PRIVATE_H
/* $Id: treeview_private.h,v 1.3 2002/03/22 17:26:54 murrayc Exp $ */


/* treeview.h
 *
 * Copyright(C) 2001 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or(at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtkmm/treeviewcolumn.h>

namespace Gtk
{

#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace TreeView_Private
{

//This Signal Proxy allows the C++ coder to specify a SigC::Slot instead of a static function.
class SignalProxy_CellData
{
public:
  typedef TreeViewColumn::SlotCellData SlotType;

  SignalProxy_CellData(const SlotType& slot);
  ~SignalProxy_CellData();

  static void gtk_callback(GtkTreeViewColumn *tree_column, GtkCellRenderer* cell, GtkTreeModel* model, GtkTreeIter* iter, gpointer data);
  static void gtk_callback_destroy(gpointer data);

protected:
  SlotType slot_;
};

} /* namespace TreeView_Private */
#endif //DOXYGEN_SHOULD_SKIP_THIS

} /* namespace Gtk */


#endif /* _GTKMM_TREEVIEW_PRIVATE_H */

==> gtkmm-2.3.3.tar.bz2: gtkmm-2.3.3/gtk/gtkmm/treeview_private.h <==
#ifndef _GTKMM_TREEVIEW_PRIVATE_H
#define _GTKMM_TREEVIEW_PRIVATE_H
/* $Id: treeview_private.h,v 1.1.1.1 2003/01/21 13:40:59 murrayc Exp $ */


/* treeview.h
 *
 * Copyright(C) 2001-2002 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or(at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtkmm/treeviewcolumn.h>

namespace Gtk
{

#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace TreeView_Private
{

//This Signal Proxy allows the C++ coder to specify a SigC::Slot instead of a static function.
class SignalProxy_CellData
{
public:
  typedef TreeViewColumn::SlotCellData SlotType;

  SignalProxy_CellData(const SlotType& slot);
  ~SignalProxy_CellData();

  static void gtk_callback(GtkTreeViewColumn*, GtkCellRenderer* cell,
                           GtkTreeModel* model, GtkTreeIter* iter, void* data);
  static void gtk_callback_destroy(void* data);

protected:
  SlotType slot_;
};


} /* namespace TreeView_Private */
#endif //DOXYGEN_SHOULD_SKIP_THIS

} /* namespace Gtk */


#endif /* _GTKMM_TREEVIEW_PRIVATE_H */
